@@ -91,7 +91,7 @@ class MediaLibraryThread(Thread):
            until __commandQuitRunning is placed in the queue and processed.
         """
         self.__blIsRunning = True
-        print "Media Library Thread Started"
+        #print "Media Library Thread Started"
         while self.__blIsRunning:
             self.__cndtnRunCommand.acquire()
             command = self.__commandEmpty
@@ -100,33 +100,33 @@ class MediaLibraryThread(Thread):
             self.__lckCommandQueue.acquire()
             command = self.__commandQueue.get(True)
             self.__lckCommandQueue.release()
-            print "\nMedia Library Thread Started Processing Command:", command
+            #print " * Media Library Thread Processing Command:", command
 
             # Signal to quit the media library
             if command == self.__commandQuitRunning:
-                print "Media Library Thread Running Signal Quit"
+                #print "Media Library Thread Running Signal Quit"
                 self.__lckCommandQueue.acquire()
                 while not self.__commandQueue.empty():
                     self.__commandQueue.get(True)
                 self.__lckCommandQueue.release()
                 self.__blIsRunning = False
-                print "Media Library Thread End Of Signal Quit"
+                #print "Media Library Thread End Of Signal Quit"
                 break
 
             # Signal to search the media library
             if command == self.__commandSearch:
-                print "Media Library Thread Running Signal Search"
+                #print "Media Library Thread Running Signal Search"
                 self.__blIsSearchDone = False
                 self.__songsFound = self.__mediaLibrary.findSongs( \
                     self.__searchTerms, \
                     self.__searchAudio, \
                     self.__searchVideo)
                 self.__blIsSearchDone = True
-                print "Media Library Thread End Of Signal Search"
+                #print "Media Library Thread End Of Signal Search"
 
-            print "Media Library Thread Finished Processing Command:", command
+            #print " * Media Library Thread Finished Command:", command
             self.__cndtnRunCommand.release()
-        print "Media Library Thread Ended"
+        #print "Media Library Thread Ended"
 
     def __pushCommand(self, command):
         """ Adds a signal command to the command queue
@@ -135,7 +135,7 @@ class MediaLibraryThread(Thread):
         """
         self.__lckCommandQueue.acquire()
         if self.__blIsRunning:
-            print "MediaLibraryThread.__pushCommand(command)", command
+            #print "MediaLibraryThread.__pushCommand(command)", command
             self.__commandQueue.put(command, True)
         self.__lckCommandQueue.release()
 
@@ -239,4 +239,15 @@ class MediaLibraryThread(Thread):
 
     def songsFound(self):
         """ Accessor to the songs found from a search. """
-        return self.__songsFound
\ No newline at end of file
+        return self.__songsFound
+
+    def incrementSongPlayed(self, song):
+        """ Increments the song counter.
+
+         Increments the song counter by one.
+         MediaSong song: is the song that is to be played.
+        """
+        self.__cndtnRunCommand.acquire()
+        self.__mediaLibrary.incrementSongPlayed(song)
+        self.__cndtnRunCommand.notify()
+        self.__cndtnRunCommand.release()
