@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -67,7 +68,7 @@ class SearchWindow(wx.Panel):
     # Search result page indicator
     __ID_PAGES = wx.NewId()
 
-    def __init__(self, parent, searchAudio=True, searchVideo=True):
+    def __init__(self, parent, iconPath, searchAudio=True, searchVideo=True):
         """ Default constructor
 
          wx.Window parent: is the parent window.
@@ -75,11 +76,11 @@ class SearchWindow(wx.Panel):
          boolean searchVideo: True if the user wants to search for video media.
         """
         wx.Panel.__init__(self, parent, wx.NewId())
-        self.__createControls(searchAudio, searchVideo)
+        self.__createControls(searchAudio, searchVideo, iconPath)
         self.__bindEvents()
         self.__doLayout()
 
-    def __createControls(self, searchAudio, searchVideo):
+    def __createControls(self, searchAudio, searchVideo, iconPath):
         """ Create the controls for the search window.
 
          boolean searchAudio: True if the user wants to search for audio media.
@@ -112,14 +113,15 @@ class SearchWindow(wx.Panel):
             "Artist")
 
         # Large list navigation
-        self.__bttnPrevious = wx.Button(self, self.__ID_PREVIOUS, \
-            "Previous Page")
-        self.__bttnPrevious.Enable(False)
+        self.__btmpBttnPrevious = wx.BitmapButton(self, self.__ID_PREVIOUS, \
+            wx.Bitmap(iconPath + '/prev.png'))
+        self.__btmpBttnPrevious.Enable(False)
         self.__spnCtrlPage = wx.SpinCtrl(self, self.__ID_PAGES, \
             style=wx.TE_READONLY)
         self.__spnCtrlPage.SetRange(0, 0)
-        self.__bttnNext = wx.Button(self, self.__ID_NEXT, "Next Page")
-        self.__bttnNext.Enable(False)
+        self.__btmpBttnNext = wx.BitmapButton(self, self.__ID_NEXT, \
+            wx.Bitmap(iconPath + '/next.png'))
+        self.__btmpBttnNext.Enable(False)
 
     def __bindEvents(self):
         """ Connects all the needed events.
@@ -155,10 +157,10 @@ class SearchWindow(wx.Panel):
         self.__bxSzrSearchNavigation.AddSpacer(5)
         self.__bxSzrSearchNavigation.Add(self.__spnCtrlPage, 0, wx.ALL, 3)
         self.__bxSzrSearchNavigation.AddSpacer(5)
-        self.__bxSzrSearchNavigation.Add(self.__bttnPrevious, 1, wx.EXPAND | \
+        self.__bxSzrSearchNavigation.Add(self.__btmpBttnPrevious, 1, wx.EXPAND | \
             wx.ALL | wx.FIXED_MINSIZE, 3)
         self.__bxSzrSearchNavigation.AddSpacer(5)
-        self.__bxSzrSearchNavigation.Add(self.__bttnNext, 1, wx.EXPAND | \
+        self.__bxSzrSearchNavigation.Add(self.__btmpBttnNext, 1, wx.EXPAND | \
             wx.ALL | wx.FIXED_MINSIZE, 3)
 
         # Search Result Layout
@@ -320,16 +322,16 @@ class SearchWindow(wx.Panel):
         """ Updates the navigation buttons based on the search results. """
         if (self.__displayedResultsStartIndex + \
                 self.__MAXIMUM_DISPLAYED_RESULTS) > len(self.__searchResults):
-            self.__bttnNext.Enable(False)
+            self.__btmpBttnNext.Enable(False)
         elif len(self.__searchResults) > self.__MAXIMUM_DISPLAYED_RESULTS:
-            self.__bttnNext.Enable(True)
+            self.__btmpBttnNext.Enable(True)
         else:
-            self.__bttnNext.Enable(False)
+            self.__btmpBttnNext.Enable(False)
 
         if self.__displayedResultsStartIndex < 1:
-            self.__bttnPrevious.Enable(False)
+            self.__btmpBttnPrevious.Enable(False)
         else:
-            self.__bttnPrevious.Enable(True)
+            self.__btmpBttnPrevious.Enable(True)
 
         if self.__displayedResultsStartIndex is not None:
             self.__spnCtrlPage.SetRange(1, len(self.__searchResults) / \
